@@ -14,6 +14,7 @@
 
 #include "atm.h"
 #include "atmd.h"
+#include "atmarpd.h"
 
 #include "table.h"
 
@@ -56,7 +57,8 @@ ENTRY *lookup_addr(const ITF *itf,const struct sockaddr_atmsvc *addr)
     ENTRY *walk;
 
     for (walk = itf->table; walk; walk = walk->next)
-	if (walk->addr && atm_equal(walk->addr,addr,0,0)) break;
+	if (walk->addr && atm_equal((struct sockaddr *) walk->addr,
+	  (struct sockaddr *) addr,0,0)) break;
     return walk;
 }
 
@@ -66,11 +68,13 @@ ENTRY *lookup_incoming(const struct sockaddr_atmsvc *addr)
     ENTRY *walk;
 
     for (walk = unknown_incoming; walk; walk = walk->next)
-	if (walk->addr && atm_equal(walk->addr,addr,0,0)) break;
+	if (walk->addr && atm_equal((struct sockaddr *) walk->addr,
+	  (struct sockaddr *) addr,0,0)) break;
     return walk;
 }
 
 
+static int table_uptodate = 0; /* ATMARP table file is up to date */
 static FILE *out_file = NULL;
 static int out_error = 0;
 
@@ -82,7 +86,7 @@ static void output(const char *fmt,...)
     va_start(ap,fmt);
     if (!out_file) vdiag(COMPONENT,DIAG_DEBUG,fmt,ap);
     else if (vfprintf(out_file,fmt,ap) < 0 || putc('\n',out_file) < 0)
-	    out_error = 1;
+	    out_error = errno;
     va_end(ap);
 }
 
@@ -120,7 +124,7 @@ static void dump_entries(ENTRY *list)
 	"???",	"com", "PERM", "PUBL",			/* 0x0001-0x0008 */
 	"trailers", "netmask", "dontpub", "magic",	/* 0x0010-0x0080 */
 	"???", "???", "???", "???",			/* 0x0100-0x0800 */
-	"NULL", "ARPSRV", "DEFQOS" };			/* 0x1000-0x8000 */
+	"NULL", "ARPSRV", "???" };			/* 0x1000-0x8000 */
     /* lower case flags are not used by ATMARP */
     ENTRY *entry;
     VCC *vcc;
@@ -169,21 +173,41 @@ static void dump_itf(ITF *itf)
 }
 
 
-void dump_all(void)
+static void dump_all(void)
 {
     ITF *itf;
 
-    if (!debug) {
-	out_file = fopen(TMP_DUMP_FILE,"w");
-	out_error = 0;
-    }
     for (itf = itfs; itf; itf = itf->next) dump_itf(itf);
     output("----- Unknown incoming connections -----");
     dump_entries(unknown_incoming);
     output("----- End of dump -----");
     if (out_file) {
-	if (fclose(out_file) < 0) out_error = 1;
-	if (!out_error) rename(TMP_DUMP_FILE,DUMP_FILE);
-	unlink(TMP_DUMP_FILE);
     }
 }
+
+
+void table_changed(void)
+{
+    table_uptodate = 0;
+    table_update(); /* @@@ sigh, fix this later */
+    if (debug) {
+	out_file = 0;
+	dump_all();
+    }
+}
+
+
+int table_update(void)
+{
+    if (table_uptodate) return 0;
+    out_file = fopen(ATMARP_TMP_DUMP_FILE,"w");
+    out_error = 0;
+    dump_all();
+    if (fclose(out_file) < 0) out_error = errno;
+    if (!out_error)
+	if (rename(ATMARP_TMP_DUMP_FILE,ATMARP_DUMP_FILE) < 0)
+	    out_error = errno;
+	else table_uptodate = 1;
+    unlink(ATMARP_TMP_DUMP_FILE);
+    return out_error;
+}
