@@ -1,11 +1,9 @@
 /*
- * mib.h - Ilmi management information base (MIB)
+ * mib.h - MIB Primitives
  *
  * Written by Scott W. Shumate
  * 
- * Copyright (c) 1995 Telecommunications & Information
- * Sciences Laboratory, The University of Kansas 
- * All Rights Reserved.
+ * Copyright (c) 1995-97 All Rights Reserved.
  * 
  * Permission to use, copy, modify and distribute this
  * software and its documentation is hereby granted,
@@ -17,19 +15,10 @@
  * acknowledged in any publications resulting from using
  * the software.
  * 
- * TISL ALLOWS FREE USE OF THIS SOFTWARE IN ITS "AS IS"
- * CONDITION AND DISCLAIMS ANY LIABILITY OF ANY KIND FOR
+ * I ALLOW FREE USE OF THIS SOFTWARE IN ITS "AS IS"
+ * CONDITION AND DISCLAIM ANY LIABILITY OF ANY KIND FOR
  * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS
  * SOFTWARE.
- * 
- * Telecommunications & Information Science Lab
- * 2291, Irving Hill Road Lawrence, KS 66046
- * (913)-864-7757
- * http://www.tisl.ukans.edu
- * 
- * The development of this software was generously
- * supported by research grants from Sprint corporation,
- * and we would like to express our thanks.
  */
 
 #ifndef MIB_H
@@ -53,4 +42,8 @@ void MIBgetnext(VarBindList *list, PDUInt *status, AsnInt *index);
 void MIBset(VarBindList *list, PDUInt *status, AsnInt *index);
 void *MIBdelete(AsnOid *oid);
 
+AsnInt getString(VarBind *varbind, Variable *var);
+AsnInt getOid(VarBind *varbind, Variable *var);
+AsnInt getInteger(VarBind *varbind, Variable *var);
+
 #endif
