@@ -36,9 +36,10 @@ typedef void (*kernel_callback)(struct atmlec_msg *mesg);
 int kernel_init(unsigned char *mac_addr, int itf_num);
 int kernel_sendmsg(atmlec_msg_type type, unsigned char *mac_addr,
 		   unsigned char *atm_addr, struct atmlec_config_msg *config,
-		   unsigned long flag);
+		   unsigned long flag, char *data, int datalen);
 int kernel_register_callback(atmlec_msg_type type, kernel_callback callback);
 void kernel_dispatch_handlers(void);
+int read_from_kernel (char *buff, int size);
 
 #endif /* KERNEL_ITF_H */
 /*
