@@ -15,19 +15,8 @@
 #include <netinet/in.h>
 #include <arpa/inet.h>
 
-#include <linux/atm.h>
-#include <linux/version.h>
-#if LINUX_VERSION_CODE >= 0x20100
+#include <atm.h>
 #include <linux/atm_tcp.h>
-#else
-
-struct atmtcp_hdr {
-    unsigned short vpi;
-    unsigned short vci;
-    unsigned short length; /* ... of data part */
-};
-
-#endif
 
 
 #define PORT 8402	/* old ATMTCP used 8401, but now the header is in
