@@ -13,8 +13,8 @@
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <sys/ioctl.h>
-#include <linux/atm.h>
 #include <linux/atmdev.h>
+#include <stdint.h> /* linux/atmsvc.h includes linux/atm.h */
 #include <linux/atmsvc.h>
 
 #include "atm.h"
