@@ -5,6 +5,7 @@
 
 #include <stdlib.h>
 
+#include <atm.h>
 #include <atmd.h>
 
 #include "../fab.h"
@@ -66,7 +67,7 @@ static int check_ci(struct sockaddr_atmpvc *pvc)
 
     if (pvc->sap_addr.vpi == ATM_VPI_ANY) pvc->sap_addr.vpi = 0;
 	/* that was easy :-) */
-    for (vci = 32; pvc->sap_addr.vci == ATM_VCI_ANY; vci++)
+    for (vci = ATM_NOT_RSV_VCI; pvc->sap_addr.vci == ATM_VCI_ANY; vci++)
 	if (!vci_exists(vci,0)) pvc->sap_addr.vci = vci;
     return !vci_exists(vci,1);
 }
