@@ -7,8 +7,11 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
+#include <string.h>
 #include <errno.h>
 
+#include <atm.h>
+
 #include "atmd.h"
 #include "fab.h"
 #include "dispatch.h"
