@@ -12,6 +12,7 @@
 #include <sys/types.h>
 
 #include <atm.h>
+#include <atmd.h>
 #include <linux/atmsvc.h>
 
 #include "isp.h"
@@ -20,16 +21,17 @@
 extern int yyparse(void);
 
 int quiet = 0;
+int verbose = 0;
 VAR *variables = NULL;
 
-static int input,output;
+static int sock;
 
 
 void send_msg(const struct atmsvc_msg *msg)
 {
     int wrote;
 
-    wrote = write(output,msg,sizeof(*msg));
+    wrote = write(sock,msg,sizeof(*msg));
     if (wrote == sizeof(*msg)) return;
     if (wrote < 0) perror("write");
     else fprintf(stderr,"bad write: %d != %d\n",wrote,sizeof(*msg));
@@ -41,7 +43,7 @@ void recv_msg(struct atmsvc_msg *msg)
 {
     int got;
 
-    got = read(input,msg,sizeof(*msg));
+    got = read(sock,msg,sizeof(*msg));
     if (got == sizeof(*msg)) return;
     if (got < 0) perror("read");
     else fprintf(stderr,"bad read: %d != %d\n",got,sizeof(*msg));
@@ -147,16 +149,16 @@ void print_value(VALUE val)
   }
 
 
-void dump_msg(const struct atmsvc_msg *msg)
+void dump_msg(const char *prefix,const struct atmsvc_msg *msg)
 {
     int fields;
 
     if (msg->type >= MSG_TYPES) {
-	printf("Unknown message type %d\n",msg->type);
+	printf("%s: unknown message type %d\n",prefix,msg->type);
 	return;
     }
     fields = types[msg->type].fields;
-    printf("Type: %s\n",types[msg->type].name);
+    printf("%s: %s\n",prefix,types[msg->type].name);
     FIELD(F_VCC,	"  vcc        = ");
     FIELD(F_LISTEN_VCC, "  listen_vcc = ");
     FIELD(F_REPLY,	"  reply      = ");
@@ -290,12 +292,12 @@ void check(VALUE a,VALUE b)
 	    if (a.u.num == b.u.num) return;
 	    break;
 	case vt_svc:
-	    if (atm_equal(&a.u.svc,&b.u.svc,0,0)) return;
+	    if (atm_equal((struct sockaddr *) &a.u.svc,
+	      (struct sockaddr *) &b.u.svc,0,0)) return;
 	    break;
 	case vt_pvc:
-	    if (a.u.pvc.sap_addr.itf == b.u.pvc.sap_addr.itf &&
-	      a.u.pvc.sap_addr.vpi == b.u.pvc.sap_addr.vpi &&
-	      a.u.pvc.sap_addr.vci == b.u.pvc.sap_addr.vci) return;
+	    if (atm_equal((struct sockaddr *) &a.u.pvc,
+	      (struct sockaddr *) &b.u.pvc,0,0)) return;
 	    break;
 	case vt_qos:
 	    if (qos_equal(&a.u.qos,&b.u.qos)) return;
@@ -422,22 +424,24 @@ int main(int argc,char **argv)
     const char *name;
 
     name = *argv;
-    if (argc > 3 && !strcmp(argv[1],"-q")) {
+    if (argc > 2 && !strcmp(argv[1],"-q")) {
 	quiet = 1;
 	argc--;
 	argv++;
     }
-    if (argc != 3) {
-	fprintf(stderr,"usage: %s [-q] input output\n",name);
+    if (argc > 2 && !strcmp(argv[1],"-v")) {
+	verbose = 1;
+	argc--;
+	argv++;
+    }
+    if (argc != 2 || (quiet && verbose)) {
+	fprintf(stderr,"usage: %s [-q | -v] socket\n",name);
 	return 1;
     }
-    if ((input = open(argv[1],O_RDWR)) < 0) { /* actually read-only */
+    sock = un_attach(argv[1]);
+    if (sock < 0) {
 	perror(argv[1]);
 	return 1;
     }
-    if ((output = open(argv[2],O_RDWR)) < 0) { /* actually write-only */
-	perror(argv[2]);
-	return 1;
-    }
     return yyparse();
 }
