@@ -33,6 +33,8 @@
  *	SGI IRIX 3.3 and 4.0 releases don't need #define SYSV.
  * Modified April 1994 by John Lin (lin@cs.purdue.edu)
  *      Add CPU_USAGE complier option and move the "gettimeofday" calls.
+ * Heavily modified since 1995 by Werner Almesberger, EPFL ICA
+ *      Various ATM-related changes
  *
  * Distribution Status -
  *      Public Domain.  Distribution Unlimited.
@@ -58,7 +60,6 @@ static char RCSid[] = "ttcp.c $Revision: 1.12 $";
 #include <arpa/inet.h>
 #include <netdb.h>
 #include <sys/time.h>		/* struct timeval */
-#include <linux/atm.h>
 #include <atm.h>
 #include <atmsap.h>
 #include <arequipa.h>
